pub struct SidebarRow {
sidebar: BoundObjectWeakRef<Sidebar>,
item: RefCell<Option<Object>>,
room_handler: RefCell<Option<SignalHandlerId>>,
room_join_rule_handler: RefCell<Option<SignalHandlerId>>,
room_is_read_handler: RefCell<Option<SignalHandlerId>>,
}Fields
The ancestor sidebar of this row.
item: RefCell<Option<Object>>The item of this row.
room_handler: RefCell<Option<SignalHandlerId>>room_join_rule_handler: RefCell<Option<SignalHandlerId>>room_is_read_handler: RefCell<Option<SignalHandlerId>>Implementations
Sourceimpl SidebarRow
impl SidebarRow
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl SidebarRow
impl SidebarRow
Set the ancestor sidebar of this row.
Sourcepub(super) fn room_category(&self) -> Option<RoomCategory>
pub(super) fn room_category(&self) -> Option<RoomCategory>
Get the RoomCategory of this row, if any.
If this does not display a room or a section containing rooms,
returns None.
Sourcepub(super) fn target_room_category(&self) -> Option<TargetRoomCategory>
pub(super) fn target_room_category(&self) -> Option<TargetRoomCategory>
Get the TargetRoomCategory of this row, if any.
Sourcepub(super) fn item_type(&self) -> Option<SidebarIconItemType>
pub(super) fn item_type(&self) -> Option<SidebarIconItemType>
Get the SidebarIconItemType of the icon item displayed by this
row, if any.
Whether this has a room context menu.
Update the context menu according to the current state.
Sourcefn room_actions(&self) -> Option<SimpleActionGroup>
fn room_actions(&self) -> Option<SimpleActionGroup>
An action group with the available room actions.
Sourcefn update_for_drop_source_category(&self)
fn update_for_drop_source_category(&self)
Update the disabled or empty state of this drop target.
Sourcefn update_for_drop_active_target_category(&self)
fn update_for_drop_active_target_category(&self)
Update the active state of this drop target.
Sourcefn drop_accept(&self, drop: &Drop) -> bool
fn drop_accept(&self, drop: &Drop) -> bool
Handle the drag-n-drop hovering this row.
Sourcefn drop_leave(&self)
fn drop_leave(&self)
Handle the drag-n-drop leaving this row.
Sourceasync fn set_room_category(&self, room: &Room, category: TargetRoomCategory)
async fn set_room_category(&self, room: &Room, category: TargetRoomCategory)
Change the category of the given room.
Sourceasync fn forget_room(&self, room: &Room)
async fn forget_room(&self, room: &Room)
Forget the given room.
Sourceasync fn set_room_is_direct(&self, room: &Room, is_direct: bool)
async fn set_room_is_direct(&self, room: &Room, is_direct: bool)
Set or unset the room as a direct chat.